from __future__ import absolute_import

from .server import xapiand_run  # NOQA
